@@ -4,15 +4,13 @@ Provides a unified namespace for building interactive UI elements.
 """
 
 from .components.base import Component as UIComponent
-from .components.inputs import Slider
-from .components.forms import Form
+from .components.form_components import Form
 from .components.data import Plot
 from .components.layout import Grid, Column
 from .components.react import ReactComponent
 
 __all__ = [
     "UIComponent",
-    "Slider",
     "Form",
     "Plot",
     "Grid",
